Module task

Module task 

Structs

Task
A structure that contains the basic information of the job.
TaskStep
A task step.

Enums

Status
Available task statuses.
TaskStepStatusErr
Possible error status values for a step’s execution.
TaskStepStatusOk
Possible success status values for a step’s execution.

Functions

run_task
Wrap a Task around a receiver, each time a command is received, forward it to the task.

Type Aliases

ExecutableFn
An executable function.